@@ -60,8 +60,8 @@ class FfmpegProcess:
                 stderr=f,
             )
 
-        input_file_info = FileInfoProviderer(filepath)
-        duration_secs = input_file_info.get_duration
+        input_file_info = FileInfoProvider(filepath)
+        duration_secs = input_file_info.get_duration()
 
         progress_bar = tqdm(
             total=duration_secs,
